global DeltaT chi12 chi23 tau omega_gm omega_em omega_0 chi0avg wgs wes delta;
DeltaT=0.05; % FWHM intensity profile in ps
tau=DeltaT/(2*sqrt(log(2))); % transform limited 1/e
omega_gm=-3.19e3;
omega_em=1.65e3;
intensity=2.88e15*2;
hbar=1.05e-34;
E0=sqrt(2*intensity/8.85e-12/3e8)/sqrt(2);
chi12=2.11e-29*E0/hbar/1e12;
chi23=2.09e-29*E0/hbar/1e12;
%allows one to specify a two photon detuning in TRad/s i.e. how far away
%from two photon resonance
delta=5*2*pi;
omega_0=0.5*((omega_em-omega_gm)+delta);
t0=-5*tau; %set the limits for integration
tfinal=5*tau;

%Now first consider the case of no adiabatic elimination
s0=[1,0,0]; % initial conditions [1,0] is all of the population in the ground state
tic % start timing the calculation
options = odeset('RelTol',1e-6,'AbsTol',[1e-7]);
%actually do the integration calling the subroutine with the differential
%equations
[t,s] = ode23('threeleveleqns2014',[t0 tfinal],s0,options); 
toc

%Now consider the case of adiabatic elimination
chi0=-1*chi12*chi23/4/(-1*omega_gm-omega_0);
chi0star=-1*chi12*chi23/4/(-1*omega_em+omega_0);
%take the average of these two to keep things Hermitian!
chi0avg=(chi0+chi0star)/2;
wgs=-2*(chi12^2/4)*omega_gm/(omega_0^2-omega_gm^2);
wes=-2*(chi23^2/4)*omega_em/(omega_0^2-omega_em^2);
s0_2=[1,0]; % two level system
tic % start timing the calculation
options = odeset('RelTol',1e-6,'AbsTol',[1e-7]);
%actually do the integration calling the subroutine with the differential
%equations
[t2,s2] = ode23('twolevelequations2014',[t0 tfinal],s0_2,options); 
toc
figure
plot(t,abs(s).^2);
hold on;
plot(t2,abs(s2).^2,'o');
%plot(t,exp(-t.^2/tau^2),'m.');
xlabel('Time [ps]'); ylabel('Population');
legend('P_{g}(t)','P_{m}(t)','P_{e}(t)','P_{g,ADEL}(t)','P_{e,ADEL}(t)');
titlestr= [',Detuning = ',num2str(delta)];
title(titlestr);
